<%@taglib uri="http://java.sun.com/jsp/jstl/core" prefix="c"%>
<%@taglib uri="http://java.sun.com/jsp/jstl/functions" prefix="fn"%>
<%@taglib uri="http://java.sun.com/jsp/jstl/fmt" prefix="fmt"%>
<%@taglib tagdir="/WEB-INF/tags/cpp" prefix="cpp"%>
<%@taglib tagdir="/WEB-INF/tags/date" prefix="date"%>
<%@taglib tagdir="/WEB-INF/tags/formatting" prefix="f" %>

<c:if test="${param.consentTypeShort eq 'wft'}">
    <%-- dealing with Withhold for Treatment Authorization (opt-out) --%>
    <c:set var="authzNoun" value="Opt-Out Request"/>
    <c:set var="authFormName" value="TBD_OPTOUT"/>
    <c:set var="consentType" value="Withhold for Treatment Authorization"/>
</c:if>

<c:if test="${param.consentTypeShort eq 'nwhin7332'}">
    <c:set var="authzNoun" value="Authorization"/>
    <c:set var="consentType" value="NwHIN Authorization"/>
    <c:choose>
        <c:when test="${enableShareNormalWithoutConsentModel}">
            <%-- new model where only 38 USC &#xa7; 7332 requires opt-in --%>
            <c:set var="authFormName" value="TBD_7332"/>
        </c:when>
        <c:otherwise>
            <%-- old require opt-in model --%>
            <c:set var="authFormName" value="10-0485"/>
        </c:otherwise>
    </c:choose>
</c:if>
<script>
    $(document).ready(function () {
        /*$("#signatureDate").datepicker({
            dateFormat: 'mm/dd/yy',
            onClose: function(dateText, inst) {
                $(this).focus();
            }
        });*/
        
        $('#signatureDate').datepicker({
            theme: 'vap',
            inputFormat: 'MM/dd/yyyy',
            outputFormat: 'MM/dd/yyyy',
            gainFocusOnConstruction: false
        });
        
        //because this page is generated dynamically, we need to set up the validator via JavaScript
        //$('#frmAuthorizeNwHIN').validator();
        
        $('#frmAuthorizeNwHIN').validator({
            custom: {
                isValidDateMMDDYYYY: function($el) { 
                    return !moment($el.val(), 'MM/DD/YYYY', true).isValid();
                }
            }
        });
        
        //call the calendar validation helper tag to remove the error classes for the date inputs and surrounding divs when tabbing/clicking off of the fields
        <date:calendarValidationHelper elementsToRemoveErrorClassesOn="divSignatureDate,signatureDate" />
        
        //if the option to delay the authorization is checked, then show that a reason is required, otherwise hide it
        $("#delayedValue").on('change', function() {
            if($('#delayedValue').prop('checked')){
                $('#reasonForDelayRequired').show();
                //we have a delayed auth here so we need to check that at least ONE is checked
                var reasonsForDelay = $("input[name='reasonsForDelay']");
                $('#divReasonsForDelayCheckboxes').show();
                $('#divReasonsForDelayLabel').show();
                if(reasonsForDelay.filter(':checked').length < 1){
                    $('.reasonsForDelayCheckbox').prop('required', true);
                    $('#divReasonsForDelayLabel').addClass('has-error has-danger');
                    $('#divReasonsForDelayCheckboxes').addClass('has-error has-danger');
                } else {
                    $('.reasonsForDelayCheckbox').prop('required', false);
                    $('#divReasonsForDelayLabel').removeClass('has-error has-danger');
                    $('#divReasonsForDelayCheckboxes').removeClass('has-error has-danger');
                }
                $('#option1').prop('disabled', true);
                $('#signatureDate').prop('disabled', true);
                $('#divSignatureDate').removeClass('has-error has-danger');
            } else {
                $('#reasonForDelayRequired').hide();
                $('.reasonsForDelayCheckbox').prop('required', false);
                $('#divReasonsForDelayLabel').removeClass('has-error has-danger');
                $('#divReasonsForDelayLabel').hide();
                $('#divReasonsForDelayCheckboxes').removeClass('has-error has-danger');
                $('#divReasonsForDelayCheckboxes').hide();
                $('#option1').prop('disabled', false);
                $('#signatureDate').prop('disabled', false);
            }
        });
        
        $('#divReasonsForDelayCheckboxes').hide();
        $('#divReasonsForDelayLabel').hide();
    });
</script>

<div class="alert alert-info">
    <p>
        The Department of Veterans Affairs (VA) is
        only capable of sharing Veteran electronic health information with
        non-VA health care providers participating in <c:out value="${organizationName}"/>. 
        Some health care providers participate in <c:out value="${organizationName}"/> by 
        contracting with a health information exchange.
        <c:if test="${param.consentTypeShort eq 'wft'}">
            By registering Form ${authFormName}, the Veteran is choosing to withhold
            sharing of his/her health information for treatment purposes (opt-out) from all non-VA 
            health care provider organizations participating in <c:out value="${organizationName}"/>
            and partnering with VA.
            <p>
                <strong>DO NOT</strong> initiate an opt-out action unless you have a valid
                opt-out request on file for the patient. NOTE: VA patient information
                is always shared with the DoD.
            </p>
            <p>
                The Veteran chooses to withhold the sharing of his/her electronic health information with non-VA 
                health care provider organizations participating in eHealth Exchange and partnering with 
                VA for treatment purposes. The VA will immediately stop sharing Veteran electronic health information.
            </p>
        </c:if>
        <c:if test="${param.consentTypeShort eq 'nwhin7332'}">
            <c:choose>
              <c:when test="${enableShareNormalWithoutConsentModel}">
                By completing the Authorization on VA Form ${authFormName}, the Veteran is authorizing VA to 
                share his/her 38 USC &#xa7; 7332 protected health information for treatment purposes with all non-VA 
                health care provider organizations participating in <c:out value="${organizationName}"/> 
                and partnering with VA. During any time that the veteran also chooses to withhold sharing
                of his/her health information for treatment purposes (opt-out), the authorization
                on 38 USC &#xa7; 7332 protected health information will have no effect.
                <p>
                    <strong>DO NOT</strong> initiate an authorize action unless you have a valid
                    authorization on file for the patient. NOTE: VA patient information
                    is always shared with the DoD. <strong>DO NOT</strong> authorize DoD
                    patients, only announce the Veteran.
                </p>
                <p>
                    The Veteran authorizes the sharing of his/her 38 USC &#xa7; 7332 protected electronic health information with non-VA 
                    health care provider organizations participating in eHealth Exchange and partnering with 
                    VA for treatment purposes. If the patient has not opted-out of the eHealth Exchange,
                    the VA will immediately share Veteran 38 USC &#xa7; 7332 protected electronic health information.
                </p>
              </c:when>
              <c:otherwise>
                By completing the 
                Authorization on VA Form 10-0485, the Veteran is authorizing VA to 
                share his/her health information for treatment purposes with all non-VA 
                health care provider organizations participating in <c:out value="${organizationName}"/> 
                and partnering with VA.
                <p>
                    <strong>DO NOT</strong> initiate an authorize action unless you have a valid
                    authorization on file for the patient. NOTE: VA patient information
                    is always shared with the DoD. <strong>DO NOT</strong> authorize DoD
                    patients, only announce the Veteran.
                </p>
                <p>
                    The Veteran authorizes the sharing of his/her electronic health information with non-VA 
                    health care provider organizations participating in eHealth Exchange and partnering with 
                    VA for treatment purposes. The VA will immediately share Veteran electronic health information.
                </p>
              </c:otherwise>
            </c:choose>
        </c:if>
    </p>
</div>
<div id="authorizeNwHINErrorMessage" class="alert alert-danger" style="display: none;" role="alert"></div>
<div>
    <form name="frmAuthorizeNwHIN" id="frmAuthorizeNwHIN" action="PatientDetails.do_sec" method="POST" class="form-horizontal" data-toggle="validator" role="form">
        <input type="text" name="hiddenText" style="visibility:hidden;display:none;" disabled="disabled" />
        <input type="hidden" name="icn" value="<c:out value="${patientDemographics.icn}"/>" /> 
        <input type="hidden" name="requestId" value="<c:out value="${requestId}"/>" /> 
        <input type="hidden" name="newLeft" value="" /> 
        <input type="hidden" name="newRight" value="" /> 
        <c:if test="${param.consentTypeShort eq 'wft'}">
            <input type="hidden" name="consentType" value="Withhold for Treatment Authorization" /> 
        </c:if>
        <c:if test="${param.consentTypeShort eq 'nwhin7332'}">
            <input type="hidden" name="consentType" value="NwHIN Authorization" /> 
        </c:if>
        <input type="hidden" name="purposeOfUse" value="TREATMENT" />
        <input type="hidden" name="expirationYears" value="10" />
        <input type="hidden" id="isDelayed" name="isDelayed" value="<c:out value="${delayedNwHINAuth}"/>" />
        <input type="hidden" name="collectedReasons" id="collectedReasons" />
        <input type="hidden" id="method" name="" value="true" /><%-- this is the method in the servlet this form goes to. get's switched from optIn to delayAuthorization depending on what is selected in the form. look at the onclick handler for btnAuthorizeNwHINModalSubmit --%>
        <div class="form-group">
            <label for="authenticatingFacility" class="col-xs-3 col-sm-3 col-md-3 col-lg-3 control-label"><f:requiredField altText="Authenticating Facility is a required field." labelText="Authenticating Facility" /></label> 
            <div class="col-xs-9 col-sm-9 col-md-9 col-lg-9">
                <select id="authenticatingFacility" name="userFacility" class="form-control" required>
                    <c:forEach var="f" items="${allowedFacilities}">
                        <option value="<c:out value="${f.facilityStation}"/>"
                            <c:choose>
                                <c:when test="${f.facilityStation eq defaultUserFacility.facilityStation}">
                                    selected
                                </c:when>
                                <c:when test="${cookie.facility.value == f.facilityStation}">
                                    selected
                                </c:when>
                            </c:choose>>
                            <c:choose>
                                <c:when test="${f.facilityName != ''}">
                                <c:out value="${f.facilityName}"/>
                            </c:when>
                                <c:otherwise>
                                ${fn:split(f.facilityDns, '.')[0]}
                            </c:otherwise>
                            </c:choose>
                            (<c:out value="${f.facilityStation}"/>)
                        </option>
                    </c:forEach>
                </select> 
            </div>
        </div>
        <div class="col-xs-offset-3 col-sm-offset-3 col-md-offset-3 col-lg-offset-3">
            <div class="margin-left-10 checkbox form-group pad-bottom-10">
                <label for="option1">
                    <input type="checkbox" name="option1" value="${authzNoun} Form Received and Validated" id="option1" required />
                    <f:requiredField altText="${authzNoun} Form Received and Validated is a required field." labelText="Form Validation for ${authzNoun} Form ${authFormName} Received and Validated" />
                </label> 
            </div>
        </div>
        <div class="form-group" id="divSignatureDate">
            <label for="signatureDate" class="col-xs-3 col-sm-3 col-md-3 col-lg-3 control-label"><f:requiredField altText="Patient Signature Date is a required field." labelText="Patient Signature Date" /></label> 
            <div class="col-xs-3 col-sm-3 col-md-3 col-lg-3">
                <input type="text" name="signatureDate" id="signatureDate" class="form-control vap-datepicker-input" data-isValidDateMMDDYYYY="isValidDateMMDDYYYY" required />
            </div>
        </div>
        <c:if test="${!delayedNwHINAuth eq 'true'}">
            <div class="form-group text-center" style="margin-top: 20px;">
                <p class="form-static-control"><strong>- OR -</strong></p>
            </div>            
            <div class="col-xs-offset-3 col-sm-offset-3 col-md-offset-3 col-lg-offset-3">
                <div class="margin-left-10 checkbox form-group pad-bottom-10">
                    <label>
                        <input type="checkbox" title="Select if ${authzNoun} is delayed" name="delayedValue" value="Delay this ${authzNoun}" id="delayedValue" onclick="enableDelayedReasons();" />
                        Delay this ${authzNoun}
                    </label>
                </div>
            </div>
            <fieldset>
                <legend class="vap-input-group-legend"></legend>
                <div class="form-group" id="divReasonsForDelayLabel">
                    <label class="col-xs-3 col-sm-3 col-md-3 col-lg-3 control-label" id="reasonsLabel"><i id="reasonForDelayRequired" style="display: none;"><f:requiredField altText="Reason for Delay is a required field." labelText="" /></i>Reason for Delay</label><%-- yeah this looks weird. its because the asterisk only shows when reason for delay is selected --%>
                </div>  
                <div class="col-xs-offset-3 col-sm-offset-3 col-md-offset-3 col-lg-offset-3 pad-bottom-20" id="divReasonsForDelayCheckboxes" style="margin-top: -29px;">
                    <div class="margin-left-10 checkbox form-group reasonsForDelayCheckbox">
                        <label>
                            <input type="checkbox" title="Form not signed" aria-labelledby="reasonsLabel" name="reasonsForDelay" id="reasonsForDelay1" onclick="collectDelayedReasons(this);" value="1" />
                            Form not signed
                        </label>
                    </div>
                    <div class="margin-left-10 checkbox form-group reasonsForDelayCheckbox">
                        <label>
                            <input type="checkbox" title="Form content altered" aria-labelledby="reasonsLabel" name="reasonsForDelay" id="reasonsForDelay2" onclick="collectDelayedReasons(this);" value="2" />
                            Form content altered
                        </label>
                    </div>
                    <div class="margin-left-10 checkbox form-group reasonsForDelayCheckbox">
                        <label>
                            <input type="checkbox" title="Demographic changes" aria-labelledby="reasonsLabel" name="reasonsForDelay" id="reasonsForDelay3" onclick="collectDelayedReasons(this);" value="3" />
                            Demographic changes
                        </label>
                    </div>
                    <div class="margin-left-10 checkbox form-group reasonsForDelayCheckbox">
                        <label>
                            <input type="checkbox" title="Privacy Officer review" aria-labelledby="reasonsLabel" name="reasonsForDelay" id="reasonsForDelay4" onclick="collectDelayedReasons(this);" value="4" />
                            Privacy Officer review
                        </label>
                    </div>
                    <div class="margin-left-10 checkbox form-group reasonsForDelayCheckbox">
                        <label>
                            <input type="checkbox" title="Signature verification" aria-labelledby="reasonsLabel" name="reasonsForDelay" id="reasonsForDelay5" onclick="collectDelayedReasons(this);" value="5" />
                            Signature verification
                        </label>
                    </div>
                    <div class="margin-left-10 checkbox form-group reasonsForDelayCheckbox">
                        <label>
                            <input type="checkbox" title="Power of Attorney not on file" aria-labelledby="reasonsLabel" name="reasonsForDelay" id="reasonsForDelay6" onclick="collectDelayedReasons(this);" value="6" />
                            Power of Attorney not on file
                        </label>
                    </div>
                </div>
            </fieldset>
        </c:if>
        <div class="form-group">
            <label for="comments" class="col-xs-3 col-sm-3 col-md-3 col-lg-3 control-label">Comments</label>
            <div class="col-xs-9 col-sm-9 col-md-9 col-lg-9">
                <textarea id="comments" name="comments" class="form-control" rows="5"></textarea>
            </div>
        </div>
    </form>
</div>