<%--
    Document   : Patient Discovery Report
    Created By : David Vasquez / Robert Snelling
    Modified By: Asha Amritraj
--%>

<%@page import="java.util.*"%>
<%@page import="java.text.SimpleDateFormat"%>
<%@taglib tagdir="/WEB-INF/tags/formatting" prefix="f" %>
<%@taglib uri="http://java.sun.com/jsp/jstl/core" prefix="c"%>
<%@taglib tagdir="/WEB-INF/tags/date" prefix="date"%>
<%@taglib tagdir="/WEB-INF/tags/cpp" prefix="cpp"%>

<%    
    Date today = new Date();
    SimpleDateFormat ft = new SimpleDateFormat ("MM/dd/yyyy");
    String maxDate = ft.format(today);

    pageContext.setAttribute("maxDate", maxDate);
%>

<f:mainTemplate headerText="Manage Batches">
    <script language="JavaScript">
        $(document).ready(function () {
            //initial data table setup and call for the first recordset
            VAP.common.setProcessingForDataTable('tblReport', 'divReportPanel');
            
            VAP.common.reportTable = $('#tblReport').DataTable({
                destroy: true,
                searching: false,
                processing: true,
                serverSide: true,
                order: [[2, 'desc']],
                columnDefs: [
                    {orderable: false, targets: [0,1,2,3,4,5,6]}, 
                    {className: "text-center vertical-align-center", targets: [0,6]},
                    {className: "text-right", targets: [3,4,5]}
                ],
                ajax: "BatchManagerQuery.do_sec?doSearch=true", 
                lengthMenu: [ 10, 25, 50, 100, 250, 500 ],
                pageLength: 25,
                "footerCallback": function ( row, data, start, end, display ) {
                    var api = this.api(), data;

                    // Update footer
                    $(api.column(3).footer() ).html(
                        api.column(3, {page:'current'}).data().sum()
                    );
            
                    $(api.column(4).footer() ).html(
                        api.column(4, {page:'current'}).data().sum()
                    );
            
                    $(api.column(5).footer() ).html(
                        api.column(5, {page:'current'}).data().sum()
                    );
                }
            });

            VAP.common.reportTable.on('draw', function () {
                VAP.common.addAriaToDataTable('tblReport', VAP.common.reportTable);
            });
            
            $("#master").change(function(){
                var status = $(this).is(":checked") ? true : false;
                $(".chk").prop("checked",status);
            });
            
            /*$("#startDate").datepicker({
                maxDate: 0,
                dateFormat: 'mm/dd/yy',
                onClose: function (selectedDate) {
                    $("#endDate").datepicker("option", "minDate", selectedDate);
                    $(this).focus();
                }
            });

            $("#endDate").datepicker({
                maxDate: 0,
                dateFormat: 'mm/dd/yy',
                onClose: function (selectedDate) {
                    $("#startDate").datepicker("option", "maxDate", selectedDate);
                    $(this).focus();
                }
            });*/
        
            $('#startDate').datepicker({
                theme: 'vap',
                inputFormat: 'MM/dd/yyyy',
                outputFormat: 'MM/dd/yyyy',
                gainFocusOnConstruction: false,
                max: '<c:out value="${maxDate}" />',
                onUpdate: function(curValue) {
                    $('#endDate').datepicker('min', curValue);
                }
            });

            $('#endDate').datepicker({
                theme: 'vap',
                inputFormat: 'MM/dd/yyyy',
                outputFormat: 'MM/dd/yyyy',
                gainFocusOnConstruction: false,
                max: '<c:out value="${maxDate}" />',
                onUpdate: function(curValue) {
                    $('#startDate').datepicker('max', curValue);
                }
            });
            
            //when the search button is pressed this function is used
            $('#btnSearch').on('click', function () {
                $('#tblReport .dataTables_empty').html(''); //blank out the empty table message if there is one
                
                var remoteOrganization = $('#remoteOrganization').val();
                var startDate = $('#startDate').val();
                var endDate = $('#endDate').val();

                var errorMessage = VAP.common.validateStartAndEndDate(startDate, endDate);

                if (errorMessage != '')
                {
                    //we have an error so show the error, and then don't send the ajax request
                    $('#errorMessage').html(errorMessage);
                    $('#errorMessage').show();

                    return false;
                } else {
                    //no error, let's make the call to populate the report
                    VAP.common.reportTable.ajax.url("BatchManagerQuery.do_sec?doSearch=true&remoteOrganization=" + remoteOrganization + "&startDate=" + startDate + "&endDate=" + endDate).load();
                }
            });
            
            $('#startDate,#endDate').on('change', function () {
                //if either date changes, hide the error message if its not already hidden
                $('#errorMessage').hide();
            });
            
            $('#batchAnnounceDetailModal').on('show.bs.modal', function (event) {
                var button = $(event.relatedTarget);
                var batchId = button.data("batch-id");
                var orgId = button.data("org-id");
                var url = 'BatchManagerQuery.do_sec?getDetailView=true&batchId=' + batchId + '&orgId=' + orgId;
                
                var modalBody = $(this).find('.modal-body');
                
                modalBody.load(url, {spinnerTargetElement : 'batchAnnounceDetailModalBody'});
            });
            $('#deleteBtn').on('click',function() {
                if(!$(':checkbox').is(':checked')){
                    $('#deleteErrorMessage').html("Selection Required to Delete");
                    $('#deleteErrorMessage').show();
                    return false;
                }
            }); 
        });
    </script>
    <div class="row">
        <div class="col-xs-12 col-sm-12 col-md-12 col-lg-12">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <div class="panel-title">
                        <a href="#" title="Close Search Criteria" aria-label="Close Search Criteria" class="vap-panel-hide-show"><i class="fa fa-minus" aria-hidden="true" data-panel-body="patientDiscoverySummaryReportSearchPanel"></i></a> Search Criteria
                    </div>
                </div>    
                <div class="panel-body" id="patientDiscoverySummaryReportSearchPanel">
                    <div class="alert alert-info">
                        Fill in the fields below to narrow your search. All dates will be included if Start Date and End Date are left blank.
                    </div>
                    <div id="errorMessage" class="alert alert-warning" style="display: none;" role="alert"></div>
                    <form name="batchAnnounceForm" id="batchAnnounceForm" class="form-horizontal">
                        <div class="form-group">
                            <label for="startDate" class="col-xs-2 col-sm-2 col-md-2 col-lg-2 control-label">Start Date</label>
                            <div class="col-xs-3 col-sm-3 col-md-3 col-lg-3" data-tooltip="<c:out value="${descriptors['manageBatchesStartDateField']}" />">
                                <input type="text" name="startDate" id="startDate" class="form-control vap-datepicker-input" placeholder="mm/dd/yyyy" />
                            </div>
                        </div>
                        <div class="form-group">
                            <label for="endDate" class="col-xs-2 col-sm-2 col-md-2 col-lg-2 control-label">End Date</label>
                            <div class="col-xs-3 col-sm-3 col-md-3 col-lg-3" data-tooltip="<c:out value="${descriptors['manageBatchesStartDateField']}" />">
                                <input type="text" name="endDate" id="endDate" class="form-control vap-datepicker-input" placeholder="mm/dd/yyyy" />
                            </div>
                        </div>
                        <div class="form-group">
                            <label title="Query based on <c:out value="${organizationName}" /> Organization from the dropdown list" for="remoteOrganization" class="col-xs-2 col-sm-2 col-md-2 col-lg-2 control-label"><c:out value="${organizationName}" /> Organization</label>
                            <div class="col-xs-3 col-sm-3 col-md-3 col-lg-3">
                                <select id="remoteOrganization" name="remoteOrganization" data-tooltip="<c:out value="${descriptors['manageBatchesEHealthOrganizationsField']}"/>" class="form-control">
                                    <option value="">ALL</option>
                                    <c:forEach var="r" items="${organizations}">
                                        <option value="<c:out value="${r.orgOid}" />"><c:out value="${r.orgName}" /></option>
                                    </c:forEach>
                                </select>
                            </div>
                        </div>
                        <div class="form-group">
                            <div class="col-xs-5 col-sm-5 col-md-5 col-lg-5 text-right">
                                <input name="btnSearch" id="btnSearch" title="Search" class="btn btn-primary" type="button" value="Search" />
                            </div>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
    <div class="row">
        <div id="divReportContent" class="col-xs-12 col-sm-12 col-md-12 col-lg-12">
            <div class="panel panel-default" id="divReportPanel">
                <div class="panel-heading">
                    <div class="panel-title">
                        <a href="#" title="Close Search Results" aria-label="Close Search Results" class="vap-panel-hide-show"><i class="fa fa-minus" aria-hidden="true" data-panel-body="batchManagerQueryResultsPanel"></i></a> Search Results
                    </div>
                </div>    
                <div class="panel-body" id="batchManagerQueryResultsPanel">
                    <div id="deleteErrorMessage" class="alert alert-warning" style="display: none;" role="alert"></div>
                    <form name="manageBatchSelectForm" id="manageBatchSelectForm" action="BatchManagerResults.do_sec" method="POST">
                        <table id="tblReport" class="table table-striped" width="100%" cellspacing="0" role="presentation">
                            <thead>
                                <tr role="row">
                                    <th role="columnheader" class="text-center"><span id="selectAllHeader" data-tooltip="<c:out value="${descriptors['manageBatchesCheckBoxHeader']}"/>" >Select All <input type="checkbox" class="vertical-align-bottom" name="master" id="master" aria-label="Select All Rows" /></span></th>
                                    <th role="columnheader" class="text-center" style="min-width: 140px;"><span id="orgNameHeader" data-tooltip="<c:out value="${descriptors['manageBatchesOrganizationHeader']}" />">Organization Name</span></th>
                                    <th role="columnheader" class="text-center" style="min-width: 120px;"><span id="dateHeader" data-tooltip="<c:out value="${descriptors['manageBatchesDateHeader']}" />">Date Created (CT)</span></th>
                                    <th role="columnheader" class="text-center"><span id="scheduledHeader" data-tooltip="<c:out value="${descriptors['manageBatchesScheduledHeader']}" />">Scheduled</span></th>
                                    <th role="columnheader" class="text-center"><span id="completedHeader" data-tooltip="<c:out value="${descriptors['manageBatchesCompletedHeader']}" />">Completed</span></th>
                                    <th role="columnheader" class="text-center"><span id="batchSizeHeader" data-tooltip="<c:out value="${descriptors['manageBatchesSizeHeader']}" />">Batch Size</span></th>
                                    <th role="columnheader" class="text-center"><span id="actionHeader" data-tooltip="<c:out value="${descriptors['manageBatchesActionHeader']}" />" data-tooltip-position="left">Action</span></th>
                                </tr>
                            </thead>
                            <tfoot>
                                <tr role="row">
                                    <%--Filled in by datatables, total--%>
                                    <td role="gridcell" class="text-left bold">Total:</td>
                                    <td role="gridcell"></td>
                                    <td role="gridcell"></td>
                                    <td role="gridcell" class="text-right bold"></td>
                                    <td role="gridcell" class="text-right bold"></td>
                                    <td role="gridcell" class="text-right bold"></td>
                                    <td role="gridcell"></td>
                                </tr>
                            </tfoot>
                        </table>
                                    
                        <input id="deleteBtn" title="Delete" class="btn btn-primary pull-right" type="submit" value="Delete" name="delete"/>
                    </form>
                </div>
            </div>
        </div>
    </div>
    <div class="modal fade" id="batchAnnounceDetailModal" tabindex="-1" role="dialog" data-backdrop="static" aria-labelledby="batchAnnounceDetailModalLabel">
        <div class="vertical-alignment-helper">
            <div class="modal-dialog vertical-align-center modal-lg" role="document">
                <div class="modal-content">
                    <div class="modal-header">
                        <h4 class="modal-title" id="batchAnnounceDetailModalLabel">Batch Announce Details</h4>
                    </div>
                    <div class="modal-body" id="batchAnnounceDetailModalBody"></div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-primary" data-dismiss="modal">Close</button>
                    </div>
                </div>
            </div>
        </div>
    </div>
</f:mainTemplate>