<%--
    Document   : facilitiesFilter
    Created on : May 18, 2016
    Author     : Irakli Kakushadze
--%>
<%--
    PARAMETERS (referenced as param.myParameter in this jsp)
    defaultUserFacility - Default facility of the current user, if any
    defaultUserFacilityName - The name of the default facility
    defaultUserFacilityStation - Station number of the default facility
    facilityFilterTooltip - To be used for the tooltip on the Select Facilities select box
    labelCols - number of columns for the label tag to be using the Boostrap grid system. defaults to 2.
    selectCols - number of columns for the select box to be using the Boostrap grid system. defaults to 4.
--%>

<%@taglib tagdir="/WEB-INF/tags/cpp" prefix="cpp" %>
<%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>

<c:set var="defaultUserFacility" value="${param.defaultUserFacility}" scope="page" />
<c:set var="lCols" value="${empty param.labelCols ? '2' : param.labelCols}" scope="page" />
<c:set var="sCols" value="${empty param.selectCols ? '4' : param.selectCols}" scope="page" />
<c:set var="labelClass" value="col-xs-${lCols} col-sm-${lCols} col-md-${lCols} col-lg-${lCols}" scope="page" />
<c:set var="selectClass" value="col-xs-${sCols} col-sm-${sCols} col-md-${sCols} col-lg-${sCols}" scope="page" />

<div class="form-group" id="facilityDiv">
    <input type="hidden" id="aggregateAtFacilityLevel" name="aggregateAtFacilityLevel" />
    <input type="hidden" id="includeUnknownVisn" name="includeUnknownVisn" />
    <input id="fd-stationNumbers" name="stationNumbers" type="hidden" value="<c:out value="${empty param.defaultUserFacility ? 'ALL' : param.defaultUserFacilityStation}" />" />

    <label for="fd-selectedFacilities" class="<c:out value="${labelClass}" /> control-label">Authenticating Facilities</label>
    <div class="<c:out value="${selectClass}" />">
        <select id="fd-selectedFacilities" name="fd-selectedFacilities" multiple="multiple" data-tooltip="<c:out value="${param.facilityFilterTooltip}" />" class="form-control">
            <option>ALL</option>
        </select>
    </div>
    <div class="col-xs-2 col-sm-2 col-md-2 col-lg-2">
        <button type="button" id="fd-selectFacilities" class="btn btn-info" data-toggle="modal" data-target="#facilitiesDialog">Select...</button><br>
        <button type="button" id="fd-selectAll" class="btn btn-info margin-top-10">Select ALL</button><br>
    </div>
</div>

<div class="modal fade" id="facilitiesDialog" tabindex="-1" role="dialog" data-backdrop="static" aria-labelledby="facilitiesModalLabel">
    <div class="vertical-alignment-helper">
        <div class="modal-dialog vertical-align-center modal-lg" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h4 class="modal-title" id="facilitiesModalLabel">Select Facilities</h4>
                </div>
                <div class="modal-body" id="facilitiesDialogBody">
                    <div class="row">
                        <div class="col-xs-12 col-sm-12 col-md-12 col-lg-12">
                            Select one or more facilities for filtering your report results. Use the left two lists to <strong>narrow down</strong> the selection list on the right.
                            You can select all available facilities or all facilities within specific VISNs by clicking "Select all" links.
                        </div>
                    </div>
                    <div id="fd-facilitiesContainer" class="pad-top-20"></div>
                    <div class="row">
                        <div class="col-xs-4 col-sm-4 col-md-4 col-lg-4">
                            <div class="checkbox">
                                <label>
                                    <input id="fd-checkbox-includeUnknownVisn" type="checkbox"/>
                                    Include consents with unknown VISN
                                </label>
                            </div>
                        </div>
                        <div class="col-xs-4 col-sm-4 col-md-4 col-lg-4">
                            <div class="checkbox">
                                <label>
                                    <input checked="checked" id="fd-groupByVisn" type="checkbox"/>
                                    Display facilities grouped by VISN
                                </label>
                            </div>
                        </div>
                        <div class="col-xs-4 col-sm-4 col-md-4 col-lg-4">
                            <div class="checkbox">
                                <label>
                                    <input id="fd-checkbox-aggregateAtFacilityLevel" type="checkbox"/>
                                    Aggregate data at the facility level
                                </label>
                            </div>
                        </div>
                    </div>
                    <div class="row pad-top-10">
                        <div class="col-xs-12 col-sm-12 col-md-12 col-lg-12 text-right">
                            <button type="button" id="fd-restoreLastSelection" class="btn btn-success" title="Restore last selection">Restore last selection</button>
                        </div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-default" data-dismiss="modal">Cancel</button>
                    <button type="button" id="facilitiesFilterOk" class="btn btn-primary" data-dismiss="modal" style="width: 53px;">OK</button>
                </div>
            </div>
        </div>
    </div>
</div>

<script>

    var facilitiesDialog = {};

    <c:if test="${not empty param.defaultUserFacility}">
        $('#fd-selectedFacilities').empty();
        $('#fd-selectedFacilities').append('<option><c:out escapeXml="true" value="${param.defaultUserFacilityName}"/></option>');
        $('input[name="stationNumbers"]').val('<c:out escapeXml="true" value="${param.defaultUserFacilityStation}"/>');
        
        $('#fd-checkbox-includeUnknownVisn').prop('checked', false);
        $('#includeUnknownVisn').val('false');
        
        $('#fd-checkbox-aggregateAtFacilityLevel').prop('checked', false);
        $('#aggregateAtFacilityLevel').val('false');
    </c:if>
    $(document).ready(function () { 
        $('#fd-checkbox-aggregateAtFacilityLevel').on('click', function () {
            facilitiesDialog.handleAggregation();
        });

        $('#facilitiesFilterOk').on('click', function () {
            var aggregate = $('#fd-checkbox-aggregateAtFacilityLevel').is(':checked');
            var stationNames = [];
            var stationNumbers = [];
            $('#fd-stationList input[type=checkbox]').each(function() {
                if ($(this).is(':visible') && $(this).is(':checked')) {
                    var stationNumber = $(this).attr('data-stationNumber');
                    var stationName = $(this).attr('data-facilityName') + ' (' + stationNumber + ')';
                    if (aggregate) {
                        if ($(this).prop('className') === 'fd-checkbox-facility') {
                            stationNames.push(stationName);
                            stationNumbers.push(stationNumber);
                        }
                    } else {
                        if ($(this).prop('className') === 'fd-checkbox-station') {
                            stationName = '&nbsp;&nbsp;&nbsp;&nbsp;' + stationName;
                        }
                        stationNames.push(stationName);
                        stationNumbers.push(stationNumber);
                    }
                }
            });

            if (aggregate) {
                if (stationNames.length === $('#fd-facilityList input[type=checkbox]').length) {
                    <%-- All facilities are checked, so we will treat the selection as 'ALL' --%>
                    var stationNames = ['ALL'];
                    var stationNumbers = ['ALL'];
                }
            } else {
                if (stationNames.length === $('#fd-stationList input[type=checkbox]').length) {
                    <%-- All facilities are checked, so we will treat the selection as 'ALL' --%>
                    var stationNames = ['ALL'];
                    var stationNumbers = ['ALL'];
                }
            }

            $('#fd-selectedFacilities').empty();
            for (var i in stationNames) {
                $('#fd-selectedFacilities').append('<option>' + stationNames[i] + '</option>');
            }
            $('input[name="stationNumbers"]').val(stationNumbers.join(','));  

            <%-- Store the current state of the dialog so that we can restore it on demand. --%>
            facilitiesDialog.storeState();

            $('#includeUnknownVisn').val($('#fd-checkbox-includeUnknownVisn').is(':checked'));
            $('#aggregateAtFacilityLevel').val($('#fd-checkbox-aggregateAtFacilityLevel').is(':checked'));
        });

        $('#facilitiesDialog').on('show.bs.modal', function () {
            $('#fd-facilitiesContainer').load('FacilitiesDialog.do_sec?getFacilitiesDialog=true', {spinnerTargetElement : 'facilitiesDialogBody'});
        });

        $('#facilitiesDialog').on('shown.bs.modal', function () {
            if (window.location.pathname.indexOf('SummaryReport') < 0) {
                $('#fd-checkbox-aggregateAtFacilityLevel').parent().hide();
            }
        });

        $('#fd-groupByVisn').on('click', function () {
            if ($(this).is(':checked')) {
                facilitiesDialog.sortFacilitiesGrouped();
            } else {
                facilitiesDialog.sortFacilitiesFlat();
            }
        });

        $('#fd-restoreLastSelection').on('click', function () {
            var state = sessionStorage.getItem('filterDialogState');
            if (state !== null) {
                var checkboxes = state.split(',');
                for (var i in checkboxes) {
                    var values = checkboxes[i].split(':');
                    var id = values[0];
                    var checked = values[1] === '1';
                    $('#' + id).prop('checked', checked);
                }
                facilitiesDialog.handleAggregation();
                facilitiesDialog.updateCheckboxes(false);
            }
        });
    });
    
    $('#fd-selectAll').click(function (event) {
        event.preventDefault();
        $('#fd-selectedFacilities').empty();
        $('#fd-selectedFacilities').append('<option>ALL</option>');
        $('input[name="stationNumbers"]').val(['ALL']);

        $('#fd-visnList input[type=checkbox]').each(function() {
           $(this).prop('checked', true);
        });
        
        $('#fd-facilityList input[type=checkbox]').each(function() {
            $(this).prop('checked', true);
        });
        
        $('#fd-stationList input[type=checkbox]').each(function() {
            $(this).prop('checked', true);
        });
    });

    facilitiesDialog.getAggregateAtFacilityLevel = function () {
        return $('#aggregateAtFacilityLevel').val();
    };

    facilitiesDialog.getIncludeUnknownVisn = function () {
        return $('#includeUnknownVisn').val();
    };

    facilitiesDialog.getSelectedStationNumbers = function () {
        return $('input[name="stationNumbers"]').val();
    };

    facilitiesDialog.handleAggregation = function () {
        var aggregateAtFacilityLevel = $('#fd-checkbox-aggregateAtFacilityLevel').is(':checked');
        $('#fd-stationList .fd-listitem-station').each(function() {
            var facilityChecked = $(this).children(0).is(':checked');
            $(this).children('.fd-div-checkbox-indented').each(function() {
                var checkbox = $(this).children('input');
                var label = $(this).children('label');
                if (aggregateAtFacilityLevel) {
                    checkbox.prop('checked', facilityChecked);
                }
                checkbox.prop('disabled', aggregateAtFacilityLevel);
                label.css('color', aggregateAtFacilityLevel ? '#767676' : 'black');
                label.css('font-weight', checkbox.is(':checked') ? 'bold' : 'normal');
                label.prop('disabled', aggregateAtFacilityLevel);
            });
        });
    };
    
    facilitiesDialog.sortFacilitiesGrouped = function () {
        <%-- Sort facility list. --%>
        var items = $('#fd-facilityList').children('.fd-listitem-facility, .fd-listitem-visn').sort(function(a, b) {
            var textA = a.attributes['data-groupedOrder'].value;
            var textB = b.attributes['data-groupedOrder'].value;
            return textA.toLowerCase() > textB.toLowerCase() ? 1 : -1;
        });
        $('#fd-facilityList').append(items);

        <%-- Sort station list. --%>
        var items = $('#fd-stationList').children('.fd-listitem-station, .fd-listitem-visn').sort(function(a, b) {
            var textA = a.attributes['data-groupedOrder'].value;
            var textB = b.attributes['data-groupedOrder'].value;
            return textA.toLowerCase() > textB.toLowerCase() ? 1 : -1;
        });
        $('#fd-stationList').append(items);

        <%-- To show/hide the VISN headers, we can simply update the checkboxes. --%>
        facilitiesDialog.updateCheckboxes(false);
    };

    facilitiesDialog.sortFacilitiesFlat = function () {
        <%-- Sort facility list. --%>
        var items = $('#fd-facilityList').children('.fd-listitem-facility').sort(function(a, b) {
            var textA = a.attributes['data-text'].value;
            var textB = b.attributes['data-text'].value;
            return textA.toLowerCase() > textB.toLowerCase() ? 1 : -1;
        });
        $('#fd-facilityList').append(items);

        <%-- Sort station list. --%>
        var items = $('#fd-stationList').children('.fd-listitem-station').sort(function(a, b) {
            var textA = a.attributes['data-text'].value;
            var textB = b.attributes['data-text'].value;
            return textA.toLowerCase() > textB.toLowerCase() ? 1 : -1;
        });
        $('#fd-stationList').append(items);

        <%-- We're showing a flat list, so we need to hide all VISN headers. --%>
        $('#fd-facilitiesContainer .fd-listitem-visn').each(function() {
            $(this).hide();
        });

        <%-- Since we're not showing VISN headers we need to get rid of the top margin adjustment. --%>
        $('#fd-facilityList').css('margin-top', '0px');
        $('#fd-stationList').css('margin-top', '0px');
    };

    facilitiesDialog.storeState = function () {
        var state = [];
        
        $('#fd-visnList input[type=checkbox]').each(function() {
            state.push($(this).prop('id') + ':' + ($(this).is(':checked') ? '1' : '0'));
        });
        
        $('#fd-facilityList input[type=checkbox]').each(function() {
            state.push($(this).prop('id') + ':' + ($(this).is(':checked') ? '1' : '0'));
        });
        
        $('#fd-stationList input[type=checkbox]').each(function() {
            state.push($(this).prop('id') + ':' + ($(this).is(':checked') ? '1' : '0'));
        });
        
        state.push('fd-checkbox-includeUnknownVisn' + ':' + ($('#fd-checkbox-includeUnknownVisn').is(':checked') ? '1' : '0'));
        
        state.push('fd-checkbox-aggregateAtFacilityLevel' + ':' + ($('#fd-checkbox-aggregateAtFacilityLevel').is(':checked') ? '1' : '0'));
        
        sessionStorage.setItem('filterDialogState', state.toString());
    };
</script>